EspNowReceiver

Struct EspNowReceiver 

pub struct EspNowReceiver { /* private fields */ }
Available on crate features esp-now and unstable only.
This is the receiver part of ESP-NOW. You can get this receiver by splitting an EspNow instance.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl EspNowReceiver

pub fn receive(&self) -> Option<ReceivedData>

Receives data from the ESP-NOW queue.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Source

impl EspNowReceiver

pub fn receive_async(&mut self) -> ReceiveFuture<'_>

This function takes mutable reference to self because the implementation of ReceiveFuture is not logically thread safe.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.